@@ -1,15 +1,30 @@
-use crate::lib_backend::schema::dir;
-use crate::lib_backend::schema::entry;
-use crate::lib_backend::schema::tag;
-use crate::lib_backend::schema::dir_tags;
-use crate::lib_backend::schema::entry_tags;
+use crate::lib_backend::schema::{user,dir,entry,tag,dir_tags,entry_tags};
 use chrono::{NaiveDateTime};
 
+#[derive(Queryable)]
+pub struct User {
+	pub id: i32,
+	pub global_id: String,
+	pub username: String,
+	pub password: String,
+	pub admin: bool,
+}
+
+#[derive(Insertable)]
+#[table_name = "user"]
+pub struct NewUser {
+	pub global_id: String,
+	pub username: String,
+	pub password: String,
+}
+
 #[derive(Queryable)]
 pub struct Dir {
 	pub id: i32,
 	pub name: String,
 	pub loc: Option<i32>,
+	pub visibility: bool,
+	pub owner: String,
 }
 
 #[derive(Insertable)]
@@ -17,6 +32,8 @@ pub struct Dir {
 pub struct NewDir<'a> {
 	pub name: &'a str,
 	pub loc: Option<i32>,
+	pub visibility: bool,
+	pub owner: String,
 }
 
 
@@ -24,12 +41,16 @@ pub struct NewDir<'a> {
 pub struct Tag {
 	pub id: i32,
 	pub name: String,
+	pub owner: String,
+	pub visibility: bool,
 }
 
 #[derive(Insertable)]
 #[table_name = "tag"]
 pub struct NewTag<'a> {
 	pub name: &'a str,
+	pub owner: &'a str,
+	pub visibility: bool,
 }
 
 #[derive(Queryable)]
@@ -54,8 +75,10 @@ pub struct Entry {
 	pub type_: String,
 	pub date_added: NaiveDateTime,
 	pub date_last_modified: NaiveDateTime,
-	pub loc: i32,
+	pub loc: Option<i32>,
 	pub label: Option<String>,
+	pub visibility: bool,
+	pub owner: String,
 }
 
 #[derive(Insertable)]
@@ -64,8 +87,10 @@ pub struct NewEntry<'a> {
 	pub name: &'a str,
 	pub data: &'a [u8],
 	pub type_: &'a str,
-	pub loc: i32,
+	pub loc: Option<i32>,
 	pub label: Option<&'a str>,
+	pub visibility: bool,
+	pub owner: &'a str
 }
 
 #[derive(Queryable)]
